@@ -55,13 +55,17 @@ class HttpRequest(object):
 
 class Http(object):
 
-    def __init__(self, endpoint, auth=None):
+    def __init__(self, endpoint, auth=None, default_headers=None):
         self.auth = auth
         self.endpoint = endpoint
+        self.default_headers = default_headers or {}
 
     def set_auth(self, auth):
         self.auth = auth
 
+    def set_header(self, k, v):
+        self.default_headers[k] = v
+
     @staticmethod
     def clean_result(resp):
         if resp.status_code >= 500:
@@ -84,6 +88,11 @@ class Http(object):
         else:
             path = '/'
 
+        if self.default_headers:
+            headers = kwargs.get('headers', {})
+            headers.update(self.default_headers)
+            kwargs['headers'] = headers
+
         url = self.endpoint.rstrip('/') + path
         req = HttpRequest(url, method=method, data=data,
                           params=params, content_type=content_type,
